DynamicTable

Struct DynamicTable 

pub struct DynamicTable<'data, Elf: FileHeader, R = &'data [u8]>
where R: ReadRef<'data>,
{ /* private fields */ }
A table of dynamic entries in an ELF file.

Also includes the string table used for the string values.

Returned by SectionTable::dynamic_table.

Implementations

Source

impl<'data, Elf: FileHeader, R: ReadRef<'data>> DynamicTable<'data, Elf, R>

pub fn strings(&self) -> &StringTable<'data, R>

Return the string table used for the dynamic entries that have string values.

pub fn dynamics(&self) -> &'data [Elf::Dyn]

Return the dynamic entry slice.

This includes the terminating null entry and any following entries, which you will usually need to skip.

pub fn iter(&self) -> DynamicIterator<'data, Elf>

Iterate over the dynamic table entries.

Excludes the terminating null entry, and any following entries.

pub fn is_empty(&self) -> bool

Return true if there are no dynamic entries.

pub fn len(&self) -> usize

The number of dynamic entries.

This includes the terminating null entry and any following entries.

pub fn string(&self, d: Dynamic) -> Result<&'data [u8]>

Return the string value for the given dynamic entry.

Does not check for an appropriate tag.