pub struct DynamicTable<'data, Elf: FileHeader, R = &'data [u8]>where
R: ReadRef<'data>,{ /* private fields */ }Expand description
A table of dynamic entries in an ELF file.
Also includes the string table used for the string values.
Returned by SectionTable::dynamic_table.
Implementations
Sourceimpl<'data, Elf: FileHeader, R: ReadRef<'data>> DynamicTable<'data, Elf, R>
impl<'data, Elf: FileHeader, R: ReadRef<'data>> DynamicTable<'data, Elf, R>
Sourcepub fn strings(&self) -> &StringTable<'data, R>
pub fn strings(&self) -> &StringTable<'data, R>
Return the string table used for the dynamic entries that have string values.
Sourcepub fn dynamics(&self) -> &'data [Elf::Dyn]
pub fn dynamics(&self) -> &'data [Elf::Dyn]
Return the dynamic entry slice.
This includes the terminating null entry and any following entries, which you will usually need to skip.
Sourcepub fn iter(&self) -> DynamicIterator<'data, Elf> ⓘ
pub fn iter(&self) -> DynamicIterator<'data, Elf> ⓘ
Iterate over the dynamic table entries.
Excludes the terminating null entry, and any following entries.